# create-lillie

```bash
create-lillie --is-empty YOUR_PROJECT_NAME
```
* create-lillie - cli name
* --is-empty - if used, will generate empty project, if not, will generate starter project
* YOUR_PROJECT_NAME - name for your project